class LocalRatingsCache
{

    constructor()
    {
        const version = Engine.GetEngineInfo().mods.filter(x => x.mod == "public")[0].version;
        const path = "config/localratings/cache/";
        this.ratingsDatabaseFile = path + version + "/ratingsDatabase.json";
        this.historyDatabaseFile = path + version + "/historyDatabase.json";
        this.scannedReplaysFile = path + version + "/scannedReplays.json";
        this.lastSettingsFile = path + version + "/lastSettings.json";
        this.createCacheFilesIfNotExist();
    }

    createCacheFilesIfNotExist()
    {
        Engine.ProfileStart("LocalRatingsCreateCacheFiles");
        for (let file of [
            this.ratingsDatabaseFile,
            this.scannedReplaysFile,
            this.lastSettingsFile
        ])
        {
            if (!Engine.FileExists(file))
                Engine.WriteJSONFile(file, {});
        }
	Engine.ProfileStop();
    }

    tagToFilename(tag)
    {
        return (tag == "ratingsDatabase") ?
            this.ratingsDatabaseFile :
            (tag == "historyDatabase") ?
            this.historyDatabaseFile :
            (tag == "scannedReplays") ?
            this.scannedReplaysFile :
            (tag == "lastSettings") ?
            this.lastSettingsFile :
            "";
    }

    load(tag)
    {
	Engine.ProfileStart("LocalRatingsLoadCacheFile");
        const file = this.tagToFilename(tag);
	const data = Engine.FileExists(file) && Engine.ReadJSONFile(file);
	Engine.ProfileStop();
        return (data) ? data : {};
    }

    save(tag, json)
    {
	Engine.ProfileStart("LocalRatingsSaveCacheFile");
        const file = this.tagToFilename(tag);
	Engine.WriteJSONFile(file, json);
	Engine.ProfileStop();
    }
    
}
