class LocalRatingsFilter
{

    constructor(replayObj)
    {
        this.duration = replayObj.duration;
        this.date = replayObj.date;
        this.populationCap = replayObj.populationCap;
        this.worldPopulation = replayObj.worldPopulation;
        this.arePlayersAI = replayObj.arePlayersAI;
        this.cheatsEnabled = replayObj.cheatsEnabled;
        this.revealedMap = replayObj.revealedMap;
        this.exploredMap = (!this.revealedMap) ? false : replayObj.exploredMap;
        this.nomad = replayObj.nomad;
        this.numberOfPlayers = replayObj.players.length;
        this.numberOfTeams = Object.keys(replayObj.teamsSize).length;
        this.unevenTeams = Object.values(replayObj.teamsSize).some(x => x != replayObj.teamsSize[Object.keys(replayObj.teamsSize)[0]]);
    }

    durationFilterApplies()
    {
        const durationValue = Engine.ConfigDB_GetValue("user", "localratings.filter.duration");
        const durationValueInt = parseInt(durationValue);
        const replayDurationMinutes = parseInt(timeToString(this.duration * 1000).split(":")[0]);
        return (replayDurationMinutes < durationValueInt);
    }

    minimumPopulationCapFilterApplies()
    {
        const minPopCapValue = Engine.ConfigDB_GetValue("user", "localratings.filter.minpopcap");
        const minPopCapValueInt = parseInt(minPopCapValue);
        return (this.populationCap < minPopCapValueInt);
    }

    maximumPopulationCapFilterApplies()
    {
        const maxPopCapValue = Engine.ConfigDB_GetValue("user", "localratings.filter.maxpopcap");
        const maxPopCapValueInt = parseInt(maxPopCapValue);
        return (this.populationCap > maxPopCapValueInt);
    }
    
    worldPopulationFilterApplies()
    {
        const worldPopulationValue = Engine.ConfigDB_GetValue("user", "localratings.filter.worldpopulation");
        const worldPopulationValueBoolean = (worldPopulationValue === "true");
        return (!worldPopulationValueBoolean && this.worldPopulation);
    }

    aiPlayersFilterApplies()
    {
        const AIPlayersValue = Engine.ConfigDB_GetValue("user", "localratings.filter.aiplayers");
        const AIPlayersValueBoolean = (AIPlayersValue === "true");
        return (!AIPlayersValueBoolean && this.arePlayersAI.some(x => x));
    }

    cheatsFilterApplies()
    {
        const cheatsValue = Engine.ConfigDB_GetValue("user", "localratings.filter.cheatsenabled");
        const cheatsValueBoolean = (cheatsValue === "true");
        return (!cheatsValueBoolean && this.cheatsEnabled);
    }

    revealedMapFilterApplies()
    {
        const revealedMapValue = Engine.ConfigDB_GetValue("user", "localratings.filter.revealedmap");
        const revealedMapValueBoolean = (revealedMapValue === "true");
        return (!revealedMapValueBoolean && this.revealedMap);
    }

    exploredMapFilterApplies()
    {
        const exploredMapValue = Engine.ConfigDB_GetValue("user", "localratings.filter.exploredmap");
        const exploredMapValueBoolean = (exploredMapValue === "true");
        return (!exploredMapValueBoolean && this.exploredMap);
    }

    nomadFilterApplies()
    {
        const nomadValue = Engine.ConfigDB_GetValue("user", "localratings.filter.nomad");
        const nomadValueBoolean = (nomadValue === "true");
        return (!nomadValueBoolean && this.nomad);
    }

    minimumNumberOfPlayersApplies()
    {
        const minPlayersValue = Engine.ConfigDB_GetValue("user", "localratings.filter.minplayers");
        const minPlayersValueInt = parseInt(minPlayersValue);
        return (this.numberOfPlayers < minPlayersValueInt);
    }

    maximumNumberOfPlayersApplies()
    {
        const maxPlayersValue = Engine.ConfigDB_GetValue("user", "localratings.filter.maxplayers");
        const maxPlayersValueInt = parseInt(maxPlayersValue);
        return (this.numberOfPlayers > maxPlayersValueInt);
    }

    minimumNumberOfTeamsApplies()
    {
        const minTeamsValue = Engine.ConfigDB_GetValue("user", "localratings.filter.minteams");
        const minTeamsValueInt = parseInt(minTeamsValue);
        return (this.numberOfTeams < minTeamsValueInt);
    }

    maximumNumberOfTeamsApplies()
    {
        const maxTeamsValue = Engine.ConfigDB_GetValue("user", "localratings.filter.maxteams");
        const maxTeamsValueInt = parseInt(maxTeamsValue);
        return (this.numberOfTeams > maxTeamsValueInt);
    }

    unevenTeamsApplies()
    {
        const unevenTeamsValue = Engine.ConfigDB_GetValue("user", "localratings.filter.uneven");
        const unevenTeamsValueBoolean = (unevenTeamsValue === "true");
        return (!unevenTeamsValueBoolean && this.unevenTeams);
    }

    recentDateApplies()
    {
        const recentDateValue = Engine.ConfigDB_GetValue("user", "localratings.filter.recentdate");
        const recentDate = recentDateValue.split("-");
        const replayDate = this.date.split("-");
        // If date is not properly formatted, we consider date filter as applicable
        if (replayDate.length != 3)
            return true;
        try
        {
            for (let i=0; i<3; i++)
            {
            if (parseInt(replayDate[i]) < parseInt(recentDate[i]))
                return true;
            }
        }
        // If date is not properly formatted, we consider date filter as applicable
        catch(error)
        {
            return true;
        }
        return false;
    }
        
    applies()
    {
        if (this.durationFilterApplies())
            return true;
        if (this.minimumPopulationCapFilterApplies())
            return true;
        if (this.maximumPopulationCapFilterApplies())
            return true;
        if (this.worldPopulationFilterApplies())
            return true;
        if (this.aiPlayersFilterApplies())
            return true;
        if (this.cheatsFilterApplies())
            return true;
        if (this.revealedMapFilterApplies())
            return true;
        if (this.exploredMapFilterApplies())
            return true;
        if (this.nomadFilterApplies())
            return true;
        if (this.minimumNumberOfPlayersApplies())
            return true;
        if (this.maximumNumberOfPlayersApplies())
            return true;
        if (this.minimumNumberOfTeamsApplies())
            return true;
        if (this.maximumNumberOfTeamsApplies())
            return true;
        if (this.unevenTeamsApplies())
            return true;
        if (this.recentDateApplies())
            return true;
        return false;
    }

}
