class LocalRatingsPlayerFilter
{

    constructor(ratingDatabase)
    {
        this.ratingDatabase = ratingDatabase;
    }

    minGamesFilterApplies(playerName)
    {
        const minGamesValue = Engine.ConfigDB_GetValue("user", "localratings.playerfilter.mingames");
        const minGamesValueInt = parseInt(minGamesValue);
        return (this.ratingDatabase[playerName].matches < minGamesValueInt);
    }

    maxGamesFilterApplies(playerName)
    {
        const limitMaxGamesValue = Engine.ConfigDB_GetValue("user", "localratings.playerfilter.limitmaxgames");
        const limitMaxGamesValueBoolean = (limitMaxGamesValue === "true");
        if (!limitMaxGamesValueBoolean)
            return false;
        const maxGamesValue = Engine.ConfigDB_GetValue("user", "localratings.playerfilter.maxgames");
        const maxGamesValueInt = parseInt(maxGamesValue);
        return (this.ratingDatabase[playerName].matches > maxGamesValueInt);
    }

    minRatingFilterApplies(playerName)
    {
        const limitMinRatingValue = Engine.ConfigDB_GetValue("user", "localratings.playerfilter.limitminrating");
        const limitMinRatingValueBoolean = (limitMinRatingValue === "true");
        if (!limitMinRatingValueBoolean)
            return false;
        const minRatingValue = Engine.ConfigDB_GetValue("user", "localratings.playerfilter.minrating");
        const minRatingValueFloat = parseFloat(minRatingValue);
        return (this.ratingDatabase[playerName].rating < minRatingValueFloat/100);
    }

    maxRatingFilterApplies(playerName)
    {
        const limitMaxRatingValue = Engine.ConfigDB_GetValue("user", "localratings.playerfilter.limitmaxrating");
        const limitMaxRatingValueBoolean = (limitMaxRatingValue === "true");
        if (!limitMaxRatingValueBoolean)
            return false;
        const maxRatingValue = Engine.ConfigDB_GetValue("user", "localratings.playerfilter.maxrating");
        const maxRatingValueFloat = parseFloat(maxRatingValue);
        return (this.ratingDatabase[playerName].rating > maxRatingValueFloat/100);
    }
    
    applies(playerName)
    {
        if (this.minGamesFilterApplies(playerName))
            return true;
        if (this.maxGamesFilterApplies(playerName))
            return true;
        if (this.minRatingFilterApplies(playerName))
            return true;
        if (this.maxRatingFilterApplies(playerName))
            return true;
        return false;
    }

    apply()
    {
        const ratingDatabaseArray = Object.entries(this.ratingDatabase);
        const filteredRatingDatabaseArray = ratingDatabaseArray.filter(([key, value]) => !this.applies(key));
        const filteredRatingDatabase = Object.fromEntries(filteredRatingDatabaseArray);
        return filteredRatingDatabase;
    }

}
