class LocalRatingsReplay
{

    constructor(metadata)
    {
        try
        {
            this.duration = this.getDuration(metadata);
            this.directory = this.getDirectory(metadata);
            this.date = this.getDate();
            const playerNames = this.getPlayerNames(metadata);
            this.players = playerNames.map(x => this.getPlayerNameWithoutRating(x));
            this.teamsSize = this.getTeamsSize(metadata);
            this.populationCap = this.getPopulationCap(metadata);
            this.worldPopulation = this.getWorldPopulation(metadata);
            this.arePlayersAI = playerNames.map(x => this.isPlayerAI(metadata, x));
            this.cheatsEnabled = this.getCheatsEnabled(metadata);
            this.revealedMap = this.getRevealedMap(metadata);
            this.exploredMap = this.getExploredMap(metadata);
            this.nomad = this.getNomad(metadata);
            this.sequences = playerNames.map(x => new LocalRatingsSequences(this.getSequences(metadata, x)));
            // Check if all keys are defined
            this.isValid = this.validate();
        }
        catch(error)
        {
            this.isValid = false;
        }
    }

    validate()
    {
        // Validate top-level keys
        if (Object.values(this).some(x => typeof x === 'undefined'))
            return false;
        // Validate sequences
        if (Object.values(this.sequences).some(x => Object.keys(x).length == 0))
            return false;
        return true;
    }

    getDuration(metadata)
    {
        return metadata.duration;
    }

    getDirectory(metadata)
    {
        return metadata.directory;
    }

    getDate()
    {
        return this.directory.split("_")[0];
    }

    getVersion(metadata)
    {
        return metadata.attribs.engine_version;
    }

    getPlayerNames(metadata)
    {
        return metadata.attribs.settings.PlayerData.map(x => x.Name);
    }

    getPlayerNameWithoutRating(playerName)
    {
        return playerName.split(" ")[0];
    }

    getTeamsSize(metadata)
    {
        let teamData = {};
        metadata.attribs.settings.PlayerData.forEach(x => (x.Team in teamData) ? teamData[x.Team] += 1 : teamData[x.Team] = 1);
        // Fix the "None" team
        if ("-1" in teamData)
            for (let i=-teamData["-1"]; i<0; i++)
                teamData[i] = 1;
        return teamData;
    }

    getPopulationCap(metadata)
    {
        if (typeof metadata.attribs.settings.WorldPopulation !== "undefined")
            return Math.floor(metadata.attribs.settings.WorldPopulationCap / this.players.length);
        return metadata.attribs.settings.PopulationCap;
    }

    getWorldPopulation(metadata)
    {
        return (typeof metadata.attribs.settings.WorldPopulation !== "undefined");
    }

    isPlayerAI(metadata, playerName)
    {
        return metadata.attribs.settings.PlayerData.filter(x => x.Name == playerName)[0].AI;
    }

    getCheatsEnabled(metadata)
    {
        return metadata.attribs.settings.CheatsEnabled;
    }

    getRevealedMap(metadata)
    {
        return metadata.attribs.settings.RevealMap;
    }

    getExploredMap(metadata)
    {
        return metadata.attribs.settings.ExploreMap;
    }

    getNomad(metadata)
    {
        return metadata.attribs.settings.Nomad;
    }

    getSequences(metadata, playerName)
    {
        const fullMetadata = Engine.GetReplayMetadata(this.directory);
        return fullMetadata.playerStates.filter(x => x.name == playerName)[0].sequences;
    }

}
