// Run this init function instead of the one declared in the gui/options/options.js
function init(data, hotloadData)
{
    g_ChangedKeys = hotloadData ? hotloadData.changedKeys : new Set();
    g_TabCategorySelected = hotloadData ? hotloadData.tabCategorySelected : 0;

    g_Options = Engine.ReadJSONFile("gui/localratings/options/options.json"); // This line is changed
    translateObjectKeys(g_Options, ["label", "tooltip"]);
    deepfreeze(g_Options);

    placeTabButtons(
	g_Options,
	false,
	g_TabButtonHeight,
	g_TabButtonDist,
	selectPanel,
	displayOptions);
}

// Return a dictionary of the form { configkey: defaultvalue } with default settings
function getDefaultSettings_LocalRatings()
{
    const optionsJSON = Engine.ReadJSONFile("gui/localratings/options/options.json")
    let settings = {};
    optionsJSON.forEach(category => category.options.forEach(option => settings[option.config] = option.val));
    return settings;
}
    
// Save default config data in user.cfg
function writeDefaultSettings_LocalRatings()
{
    const settings = getDefaultSettings_LocalRatings();
    for (const key in settings)
    {
        if (! Engine.ConfigDB_GetValue("user", key))
        {
            Engine.ConfigDB_CreateValue("user", key, settings[key]);
            Engine.ConfigDB_WriteFile("user", "config/user.cfg");
        }
    }
}

// Wrapper for the "displayOptions" function
function displayOptions_Wrapper_LocalRatings(target, args)
{
    // Run additional code
    writeDefaultSettings_LocalRatings();
    // Run original function
    target(...args);
};

// Handler for the "displayOptions" function
const displayOptions_Handler_LocalRatings = {
    apply: function(target, thisArg, args) {
        return displayOptions_Wrapper_LocalRatings(target, args);
    }
};

// Proxy the "displayOptions" function
displayOptions = new Proxy(displayOptions, displayOptions_Handler_LocalRatings);
